@@ -9,10 +9,9 @@ if os.system('python -c "import tensorflow"') == 0:
     print("Tensorflow: ", tensorflow.__version__)  # pylint: disable=no-member
 else:
     print("Import tensorflow error. Try to reinstall tensorflow.")
+    tfversion = os.environ.get("TENSORFLOW_VERSION", "1.12.0")
     os.system(
-        "pip install tensorflow=={}".format(
-            os.environ.get("TENSORFLOW_VERSION", "1.12.0")
-        )
+        f"pip install tensorflow=={tfversion}"
     )
     import tensorflow
 
