@@ -1,11 +1,12 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
+from suanpan import asyncio
 from suanpan.g import g
 from suanpan.run import cli, env, run
 
-__version__ = "0.10.14"
+__version__ = "0.12.61"
 
 
 if __name__ == "__main__":
-    print("Suanpan SDK (ver: {})".format(__version__))
+    print(f"Suanpan SDK (ver: {__version__})")
