@@ -1,7 +1,9 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
-from suanpan.api import oss
+from suanpan import asyncio
+from suanpan.api import app, component, oss
+from suanpan.api.hardware import Hardware
 from suanpan.api.requests import affinity, host
 
 get = host.get
