@@ -7,7 +7,8 @@ import hmac
 
 import requests
 
-from suanpan import g, utils
+from suanpan import error, g, utils
+from suanpan.log import logger
 
 
 def signatureV1(secret, data):
@@ -17,7 +18,7 @@ def signatureV1(secret, data):
 
 def defaultHeaders():
     if not g.userIdHeaderField:
-        raise Exception("Suanpan API call Error: userIdHeaderField not set")
+        raise error.ApiError("UserIdHeaderField not set")
     return {
         g.userIdHeaderField: g.userId,
         g.userSignatureHeaderField: signatureV1(g.accessSecret, g.userId),
@@ -25,18 +26,23 @@ def defaultHeaders():
     }
 
 
-def session():
+def session(auth=True):
     sess = requests.Session()
-    sess.headers.update(defaultHeaders())
+    if auth:
+        sess.headers.update(defaultHeaders())
     return sess
 
 
 def request(method, url, *args, **kwargs):
-    sess = session()
+    sess = session(auth=kwargs.get("auth", True))
     func = getattr(sess, method)
     rep = func(url, *args, **kwargs)
+    logger.debug(f"[{rep.status_code}] {rep.url} - {rep.request.method} - {rep.content}")
     rep.raise_for_status()
-    return rep.json()
+    result = rep.json()
+    if not result.get("success", True):
+        raise error.ApiError(f"Request failed {result}")
+    return result
 
 
 def get(url, *args, **kwargs):
