@@ -1,7 +1,7 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
-from suanpan import g
+from suanpan import error, g
 from suanpan.api import requests
 
 
@@ -11,9 +11,9 @@ def getAffinityUrl(path, tls=g.hostTls):
 
     if g.host:
         protocol = "https" if tls else "http"
-        return "{}://{}{}".format(protocol, g.host, path)
+        return f"{protocol}://{g.host}{path}"
 
-    raise Exception("Suanpan API call Error: affinity and host not set")
+    raise error.ApiError("affinity and host not set")
 
 
 def get(path, *args, **kwargs):
