@@ -18,11 +18,11 @@ class DockerComponent(Component, HasBaseServices, HasDevMode):
 
     def beforeInit(self):
         logger.logDebugInfo()
-        logger.debug("DockerComponent {} starting...".format(self.name))
+        logger.debug(f"DockerComponent {self.name} starting...")
 
     def initBase(self, args):
         logger.setLogger(self.name)
         self.setBaseServices(args)
 
     def afterSave(self, context):  # pylint: disable=unused-argument
-        logger.debug("DockerComponent {} done.".format(self.name))
+        logger.debug(f"DockerComponent {self.name} done.")
