@@ -21,22 +21,19 @@ class Table(DWArg):
     def isSet(self):
         return True
 
-    def addParserArguments(self, parser):
-        self.table.addParserArguments(parser)
-        self.partition.addParserArguments(parser)
-
     def load(self, args):
         self.table.load(args)
         self.partition.load(args)
         if self.table.value:
             self.value = {"table": self.table.value, "partition": self.partition.value}
+        return self
 
-    def format(self, context):
-        if self.value:
-            self.value = dw.readTable(self.table.value, self.partition.value)
-        return self.value
+    def transform(self, value):
+        if not value:
+            return None
+        return dw.readTable(self.table.value, self.partition.value)
 
-    def save(self, context, result):
+    def save(self, result):
         data = result.value
         dw.writeTable(self.table.value, data)
         self.logSaved(self.table.value)
@@ -46,4 +43,4 @@ class Table(DWArg):
         value = self.getOutputTmpValue(  # pylint: disable=assignment-from-no-return
             *args
         )
-        return ("--{}".format(self.table.key), value) if value is not None else tuple()
+        return (f"--{self.table.key}", value) if value is not None else tuple()
