@@ -34,3 +34,6 @@ class DataWarehouse(base.RelationalDataWarehouse):
 
         yield connection
         connection.close()
+
+    def getColumnsNamesFromCursor(self, cursor):
+        return cursor.column_names
