@@ -39,3 +39,6 @@ class DataWarehouse(base.RelationalDataWarehouse):
 
         yield connection
         connection.close()
+
+    def getColumnsNamesFromCursor(self, cursor):
+        return [column[0] for column in cursor.description]
