@@ -1,8 +1,9 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
-from suanpan.node import node
+from suanpan import error
 from suanpan.arguments.auto import ProxyArg
+from suanpan.node import node
 
 
 class DataFrame(ProxyArg):
@@ -14,9 +15,8 @@ class DataFrame(ProxyArg):
     def __init__(self, key, table, partition, *args, **kwargs):
         port = node.get(table) or node.get(key)
         if not port:
-            raise Exception(
-                "No such {}: {}".format(self.name, ",".join([key, table, partition]))
-            )
+            argsString = f"key={key}, table={table}, partition={partition}"
+            raise error.NodeError(f"No such {self.name}: {argsString}")
         kwargs.setdefault(self.TYPE_KEY, port.type)
         kwargs.update(key=key, table=table, partition=partition)
         super(DataFrame, self).__init__(*args, **kwargs)
