@@ -1,7 +1,7 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
-from suanpan import path, runtime
+from suanpan import error, path, runtime
 from suanpan.state.base import IndexSaver, Saver, TimeSaver
 from suanpan.storage import storage
 
@@ -16,7 +16,7 @@ class StorageSaver(Saver):
     def currentPattern(self):
         _pattern = self.current.pattern or self.PATTERN
         if not _pattern:
-            raise Exception("Pattern is not set!")
+            raise error.StateError("Pattern is not set!")
         return _pattern.format(**self.current)
 
     def update(self):
