@@ -4,14 +4,13 @@ from __future__ import absolute_import, division, print_function
 import functools
 import math
 import os
-import tempfile
 
 import oss2
 from lostc import collection as lcc
 from oss2.models import PartInfo
 from oss2.resumable import ResumableDownloadStore, ResumableStore
 
-from suanpan import api, asyncio
+from suanpan import api, asyncio, g
 from suanpan import path as spath
 from suanpan import runtime
 from suanpan.log import logger
@@ -30,15 +29,19 @@ class Storage(base.Storage):
         ossBucketName="suanpan",
         ossEndpoint="http://oss-cn-beijing.aliyuncs.com",
         ossDelimiter="/",
-        ossTempStore=tempfile.gettempdir(),
+        ossTempStore=base.Storage.DEFAULT_TEMP_DATA_STORE,
+        ossGlobalStore=base.Storage.DEFAULT_GLOBAL_DATA_STORE,
         ossDownloadNumThreads=1,
         ossDownloadStoreName=".py-oss-download",
         ossUploadNumThreads=1,
         ossUploadStoreName=".py-oss-upload",
-        **kwargs
+        **kwargs,
     ):
         super(Storage, self).__init__(
-            delimiter=ossDelimiter, tempStore=ossTempStore, **kwargs
+            delimiter=ossDelimiter,
+            tempStore=ossTempStore,
+            globalStore=ossGlobalStore,
+            **kwargs,
         )
 
         self.bucketName = ossBucketName
@@ -57,14 +60,31 @@ class Storage(base.Storage):
 
         self._removeOssLogger()
 
-    def ossRequest(self, apiName, *args, **kwargs):
-        apiFunc = getattr(oss2, apiName)
+    def autoRefreshToken(self, func):
+        @functools.wraps(func)
+        def _dec(*args, **kwargs):
+            try:
+                return func(*args, **kwargs)
+            except oss2.exceptions.OssError as e:
+                if e.status != 403:
+                    raise e
+                logger.warning("Oss access denied, refreshing access key.")
+                self.refreshAccessKey()
+                return func(*args, **kwargs)
+
+        return _dec
+
+    def autoRefreshBucket(self, bucket):
         try:
-            return apiFunc(*args, **kwargs)
-        except oss2.exceptions.AccessDenied:
+            bucket.object_exists(f"studio/{g.userId}/permissions")
+            return bucket
+        except oss2.exceptions.OssError as e:
+            if e.status != 403:
+                raise e
             logger.warning("Oss access denied, refreshing access key.")
             self.refreshAccessKey()
-            return apiFunc(*args, **kwargs)
+            bucket = self.getBucketByName(bucket.bucket_name)
+            return bucket
 
     def refreshAccessKey(self, accessId=None, accessKey=None):
         if accessId and accessKey:
@@ -92,13 +112,13 @@ class Storage(base.Storage):
         return _logger
 
     @runtime.retry(stop_max_attempt_number=3)
-    def download(self, name, path, bucketOrBucketName=None, ignores=None, workers=None):
+    def download(self, name, path, bucketOrBucketName=None, ignores=None):
         bucket = self.getBucket(bucketOrBucketName)
         ignores = ignores or self.DEFAULT_IGNORE_KEYWORDS
         downloadFunction = (
             self.downloadFile
             if self.isFile(name, bucketOrBucketName=bucket)
-            else functools.partial(self.downloadFolder, workers=workers)
+            else self.downloadFolder
         )
         return downloadFunction(name, path, bucketOrBucketName=bucket, ignores=ignores)
 
@@ -108,7 +128,6 @@ class Storage(base.Storage):
         folderPath,
         delimiter=None,
         bucketOrBucketName=None,
-        workers=None,
         ignores=None,
     ):
         bucket = self.getBucket(bucketOrBucketName)
@@ -117,9 +136,7 @@ class Storage(base.Storage):
         storagePath = self.storageUrl(folderName, bucketOrBucketName=bucket)
 
         if folderPath in ignores:
-            logger.info(
-                "Ignore downloading folder: {} -> {}".format(folderPath, storagePath)
-            )
+            logger.debug(f"Ignore downloading folder: {folderPath} -> {storagePath}")
             return folderPath
 
         downloads = {
@@ -132,14 +149,12 @@ class Storage(base.Storage):
             for file in files
         }
 
-        logger.info("Downloading folder: {} -> {}".format(storagePath, folderPath))
+        logger.info(f"Downloading folder: {storagePath} -> {folderPath}")
         # Download from oss
         _run = functools.partial(
             self.downloadFile, bucketOrBucketName=bucket, ignores=ignores, quiet=True
         )
-        asyncio.starmap(
-            _run, downloads.items(), pbar="Downloading", thread=True, workers=workers
-        )
+        asyncio.starmap(_run, downloads.items(), pbar="Downloading")
         # Remove ignores
         self.removeIgnores(folderPath, ignores=ignores)
         # Remove rest files and folders
@@ -150,15 +165,12 @@ class Storage(base.Storage):
         )
         restFiles = [file for file in files if file not in downloads.values()]
         asyncio.map(
-            spath.remove,
-            restFiles,
-            pbar="Removing Rest Files" if restFiles else False,
-            thread=True,
+            spath.remove, restFiles, pbar="Removing Rest Files" if restFiles else False,
         )
         spath.removeEmptyFolders(folderPath)
-        logger.info("Removed empty folders in: {}".format(folderPath))
+        logger.debug(f"Removed empty folders in: {folderPath}")
         # End
-        logger.info("Downloaded folder: {} -> {}".format(storagePath, folderPath))
+        logger.debug(f"Downloaded folder: {storagePath} -> {folderPath}")
         return folderPath
 
     def downloadFile(
@@ -170,7 +182,7 @@ class Storage(base.Storage):
         fileSize = self.getStorageSize(objectName, bucketOrBucketName=bucket)
 
         if not quiet:
-            logger.info("Downloading file: {} -> {}".format(storagePath, filePath))
+            logger.info(f"Downloading file: {storagePath} -> {filePath}")
 
         with spbar.one(total=fileSize, config=not quiet) as pbar:
             if filePath in ignores:
@@ -191,8 +203,7 @@ class Storage(base.Storage):
                     pbar.set_description("Downloading")
 
             spath.safeMkdirsForFile(filePath)
-            self.ossRequest(
-                "resumable_download",
+            self.autoRefreshToken(oss2.resumable_download)(
                 bucket,
                 objectName,
                 filePath,
@@ -206,32 +217,21 @@ class Storage(base.Storage):
             return filePath
 
     @runtime.retry(stop_max_attempt_number=3)
-    def upload(self, name, path, bucketOrBucketName=None, ignores=None, workers=None):
+    def upload(self, name, path, bucketOrBucketName=None, ignores=None):
         bucket = self.getBucket(bucketOrBucketName)
         ignores = ignores or self.DEFAULT_IGNORE_KEYWORDS
-        uploadFunction = (
-            functools.partial(self.uploadFolder, workers=workers)
-            if os.path.isdir(path)
-            else self.uploadFile
-        )
+        uploadFunction = self.uploadFolder if os.path.isdir(path) else self.uploadFile
         return uploadFunction(name, path, bucketOrBucketName=bucket, ignores=ignores)
 
     def uploadFolder(
-        self,
-        folderName,
-        folderPath,
-        bucketOrBucketName=None,
-        workers=None,
-        ignores=None,
+        self, folderName, folderPath, bucketOrBucketName=None, ignores=None,
     ):
         bucket = self.getBucket(bucketOrBucketName)
         ignores = ignores or self.DEFAULT_IGNORE_KEYWORDS
         storagePath = self.storageUrl(folderName, bucketOrBucketName=bucket)
 
         if folderName in ignores:
-            logger.info(
-                "Ignore uploading folder: {} -> {}".format(folderName, storagePath)
-            )
+            logger.debug(f"Ignore uploading folder: {folderName} -> {storagePath}")
             return folderPath
 
         filePaths = (
@@ -247,9 +247,9 @@ class Storage(base.Storage):
         }
 
         if not uploads:
-            logger.warning("Uploading empty folder: {}".format(folderPath))
+            logger.warning(f"Uploading empty folder: {folderPath}")
         else:
-            logger.info("Uploading folder: {} -> {}".format(folderPath, storagePath))
+            logger.info(f"Uploading folder: {folderPath} -> {storagePath}")
             # Upload files to oss
             uploadItems = [
                 (objectName, filePath) for filePath, objectName in uploads.items()
@@ -257,9 +257,7 @@ class Storage(base.Storage):
             _run = functools.partial(
                 self.uploadFile, bucketOrBucketName=bucket, ignores=ignores, quiet=True
             )
-            asyncio.starmap(
-                _run, uploadItems, pbar="Uploading", thread=True, workers=workers
-            )
+            asyncio.starmap(_run, uploadItems, pbar="Uploading")
 
         # Remove rest files
         localFiles = set(
@@ -275,13 +273,10 @@ class Storage(base.Storage):
         ]
         _run = functools.partial(self.remove, bucketOrBucketName=bucket, quiet=True)
         asyncio.map(
-            _run,
-            restFiles,
-            pbar="Removing Rest Files" if restFiles else False,
-            thread=True,
+            _run, restFiles, pbar="Removing Rest Files" if restFiles else False,
         )
         # End
-        logger.info("Uploaded folder: {} -> {}".format(folderPath, storagePath))
+        logger.debug(f"Uploaded folder: {folderPath} -> {storagePath}")
         return folderPath
 
     def uploadFile(
@@ -293,7 +288,7 @@ class Storage(base.Storage):
         fileSize = self.getLocalSize(filePath)
 
         if not quiet:
-            logger.info("Uploading file: {} -> {}".format(filePath, storagePath))
+            logger.info(f"Uploading file: {filePath} -> {storagePath}")
 
         with spbar.one(total=fileSize, config=not quiet) as pbar:
             if filePath in ignores:
@@ -313,8 +308,7 @@ class Storage(base.Storage):
                     pbar.update(consumed_bytes - pbar.n)
                     pbar.set_description("Uploading")
 
-            self.ossRequest(
-                "resumable_upload",
+            self.autoRefreshToken(oss2.resumable_upload)(
                 bucket,
                 objectName,
                 filePath,
@@ -329,28 +323,23 @@ class Storage(base.Storage):
             return filePath
 
     @runtime.retry(stop_max_attempt_number=3)
-    def copy(self, name, dist, bucketOrBucketName=None, workers=None):
+    def copy(self, name, dist, bucketOrBucketName=None):
         bucket = self.getBucket(bucketOrBucketName)
         copyFunction = (
             self.copyFile
             if self.isFile(name, bucketOrBucketName=bucket)
-            else functools.partial(self.copyFolder, workers=workers)
+            else self.copyFolder
         )
         return copyFunction(name, dist, bucketOrBucketName=bucket)
 
     def copyFolder(
-        self,
-        folderName,
-        distName,
-        bucketOrBucketName=None,
-        workers=None,
-        delimiter=None,
+        self, folderName, distName, bucketOrBucketName=None, delimiter=None,
     ):
         bucket = self.getBucket(bucketOrBucketName)
         delimiter = delimiter or self.delimiter
         folderName = self.completePath(folderName)
         distName = self.completePath(distName)
-        logger.info("Copying folder: {} -> {}".format(folderName, distName))
+        logger.info(f"Copying folder: {folderName} -> {distName}")
         copyItems = [
             (file, file.replace(folderName, distName))
             for _, _, files in self.walk(
@@ -359,7 +348,7 @@ class Storage(base.Storage):
             for file in files
         ]
         _run = functools.partial(self.copyFile, bucketOrBucketName=bucket, quiet=True)
-        asyncio.starmap(_run, copyItems, pbar="Copying", thread=True, workers=workers)
+        asyncio.starmap(_run, copyItems, pbar="Copying")
 
     def copyFile(self, objectName, distName, bucketOrBucketName=None, quiet=False):
         bucket = self.getBucket(bucketOrBucketName)
@@ -379,12 +368,9 @@ class Storage(base.Storage):
         bucket = self.getBucket(bucketOrBucketName)
 
         if not quiet:
-            logger.info(
-                "Copying file: {} -> {}".format(
-                    self.storageUrl(objectName, bucketOrBucketName=bucket),
-                    self.storageUrl(distName, bucketOrBucketName=bucket),
-                )
-            )
+            _src = self.storageUrl(objectName, bucketOrBucketName=bucket)
+            _target = self.storageUrl(distName, bucketOrBucketName=bucket)
+            logger.info(f"Copying file: {_src} -> {_target}")
 
         with spbar.one(total=size, config=not quiet) as pbar:
             objectMd5 = self.getStorageMd5(objectName, bucketOrBucketName=bucket)
@@ -404,12 +390,9 @@ class Storage(base.Storage):
         bucket = self.getBucket(bucketOrBucketName)
 
         if not quiet:
-            logger.info(
-                "Copying file: {} -> {}".format(
-                    self.storageUrl(objectName, bucketOrBucketName=bucket),
-                    self.storageUrl(distName, bucketOrBucketName=bucket),
-                )
-            )
+            _src = self.storageUrl(objectName, bucketOrBucketName=bucket)
+            _target = self.storageUrl(distName, bucketOrBucketName=bucket)
+            logger.info(f"Copying file: {_src} -> {_target}")
 
         with spbar.one(total=size, config=not quiet) as pbar:
             objectMd5 = self.getStorageMd5(objectName, bucketOrBucketName=bucket)
@@ -419,8 +402,8 @@ class Storage(base.Storage):
                 pbar.set_description("Existed")
                 return distName
 
-            partSize = self.ossRequest(
-                "determine_part_size", size, preferred_size=self.PREFERRED_SIZE
+            partSize = self.autoRefreshToken(oss2.determine_part_size)(
+                size, preferred_size=self.PREFERRED_SIZE
             )
             uploadId = bucket.init_multipart_upload(distName).upload_id
             parts = math.ceil(size / partSize)
@@ -448,31 +431,21 @@ class Storage(base.Storage):
 
     @runtime.retry(stop_max_attempt_number=3)
     def remove(
-        self,
-        objectName,
-        delimiter=None,
-        bucketOrBucketName=None,
-        quiet=False,
-        workers=None,
+        self, objectName, delimiter=None, bucketOrBucketName=None, quiet=False,
     ):
         delimiter = delimiter or self.delimiter
         bucket = self.getBucket(bucketOrBucketName)
         removeFunc = (
             self.removeFile
             if self.isFile(objectName, bucketOrBucketName=bucket)
-            else functools.partial(self.removeFolder, workers=workers)
+            else self.removeFolder
         )
         return removeFunc(
             objectName, delimiter=delimiter, bucketOrBucketName=bucket, quiet=quiet
         )
 
     def removeFolder(
-        self,
-        folderName,
-        delimiter=None,
-        bucketOrBucketName=None,
-        workers=None,
-        quiet=False,
+        self, folderName, delimiter=None, bucketOrBucketName=None, quiet=False,
     ):
         delimiter = delimiter or self.delimiter
         bucket = self.getBucket(bucketOrBucketName)
@@ -484,11 +457,7 @@ class Storage(base.Storage):
             self.remove, delimiter=delimiter, bucketOrBucketName=bucket, quiet=True
         )
         asyncio.map(
-            _run,
-            removes,
-            pbar="Removing" if removes and not quiet else False,
-            thread=True,
-            workers=workers,
+            _run, removes, pbar="Removing" if removes and not quiet else False,
         )
         return folderName
 
@@ -499,7 +468,7 @@ class Storage(base.Storage):
         bucket.delete_object(fileName)
         if not quiet:
             storagePath = self.storageUrl(fileName, bucketOrBucketName=bucket)
-            logger.info("Removed file: {}".format(storagePath))
+            logger.info(f"Removed file: {storagePath}")
         return fileName
 
     def walk(self, folderName, delimiter=None, bucketOrBucketName=None):
@@ -508,16 +477,13 @@ class Storage(base.Storage):
         root = self.completePath(folderName, delimiter=delimiter)
         objects = (
             obj
-            for obj in self.ossRequest(
-                "ObjectIterator", bucket, delimiter=delimiter, prefix=root
+            for obj in runtime.saferun(self._listAll, default=iter(()))(
+                folderName, delimiter=delimiter, bucketOrBucketName=bucket
             )
             if obj.key != root
         )
         folders, files = lcc.divide(objects, lambda obj: obj.is_prefix())
         folders, files = self._getObjectNames(folders), self._getObjectNames(files)
-        if not folders and not files:
-            storagePath = self.storageUrl(root, bucketOrBucketName=bucket)
-            raise Exception("Oss Error: No such folder: {}".format(storagePath))
         yield root, folders, files
         for folder in folders:
             for item in self.walk(
@@ -533,8 +499,8 @@ class Storage(base.Storage):
         )
         return (
             obj
-            for obj in self.ossRequest(
-                "ObjectIterator", delimiter=delimiter, prefix=prefix, bucket=bucket
+            for obj in self.autoRefreshToken(oss2.ObjectIterator)(
+                delimiter=delimiter, prefix=prefix, bucket=bucket
             )
         )
 
@@ -588,7 +554,7 @@ class Storage(base.Storage):
         return "oss:///" + self.storagePathJoin(bucket.bucket_name, path)
 
     def getBucket(self, bucketOrBucketName):
-        return (
+        return self.autoRefreshBucket(
             bucketOrBucketName
             if isinstance(bucketOrBucketName, oss2.Bucket)
             else self.getBucketByName(bucketOrBucketName)
